@@ -25,6 +25,7 @@
 #endif
 
 #include <libtracker-sparql/tracker-sparql.h>
+#include "tracker-module-manager.h"
 
 G_BEGIN_DECLS
 
@@ -49,10 +50,6 @@ G_BEGIN_DECLS
  * An example of how to write an extractor to retrieve PNG embedded
  * metadata.
  * <programlisting>
- *  static void extract_png (const gchar          *filename,
- *                           TrackerSparqlBuilder *preupdate,
- *                           TrackerSparqlBuilder *metadata);
- *
  *  /&ast; Set functions to use to extract different mime types. &ast;/
  *  static TrackerExtractData extract_data[] = {
  *          { "image/png",  extract_png },
@@ -60,10 +57,12 @@ G_BEGIN_DECLS
  *          { NULL, NULL }
  *  };
  *
- *  static void
- *  extract_png (const gchar          *uri,
- *               TrackerSparqlBuilder *preupdate,
- *               TrackerSparqlBuilder *metadata)
+ *  G_MODULE_EXPORT gboolean
+ *  tracker_extract_get_metadata (const gchar          *uri,
+ *                                const gchar          *mimetype,
+ *                                TrackerSparqlBuilder *preupdate,
+ *                                TrackerSparqlBuilder *metadata,
+ *                                GString              *where)
  *  {
  *          gint height, width;
  *
@@ -83,28 +82,39 @@ G_BEGIN_DECLS
  *          tracker_sparql_builder_object_int64 (metadata, height);
  *
  *          g_free (filename);
- *  }
  *
- *  TrackerExtractData *
- *  tracker_extract_get_data (void)
- *  {
- *          return extract_data;
+ *          /&ast; Were we successful or not? &ast;/
+ *          return TRUE;
  *  }
  * </programlisting>
  * </example>
  *
+ * NOTE: This example has changed subtly since 0.10. For details see
+ * tracker_extract_get_metadata().
+ *
+ * Since: 0.12
  */
 
+gboolean tracker_extract_module_init     (TrackerModuleThreadAwareness  *thread_awareness_ret,
+                                          GError                       **error);
+gboolean tracker_extract_module_shutdown (void);
 
 /**
- * TrackerExtractMimeFunc:
+ * tracker_extract_get_metadata:
  * @uri: a string representing a URI.
+ * @mimetype: mimetype for the element contained in URI
  * @preupdate: used to populate with data updates that
  *             are a prerequisite for the actual file
  *             metadata insertion.
  * @metadata: used to populate with file metadata predicate/object(s).
+ * @where: used for optional WHERE patterns
  *
- * Extracts metadata from a file, and inserts it into @metadata.
+ * This function must be provided by ALL extractors. This is merely
+ * the declaration of the function which must be written by each
+ * extractor.
+ *
+ * This is checked by tracker-extract by looking up the symbols for
+ * each started plugin and making sure this function exists.
  *
  * The @metadata parameter is a #TrackerSparqlBuilder constructed
  * through tracker_sparql_builder_new_embedded_insert(), the subject
@@ -119,64 +129,21 @@ G_BEGIN_DECLS
  * added to @preupdate, which is a #TrackerSparqlBuilder constructed.
  * through tracker_sparql_builder_new_update().
  *
- * Since: 0.8
- **/
-typedef void (*TrackerExtractMimeFunc) (const gchar          *uri,
-                                        TrackerSparqlBuilder *preupdate,
-                                        TrackerSparqlBuilder *metadata);
-
-/**
- * TrackerExtractData:
- * @mime: a string pointer representing a mime type.
- * @func: a function to extract extract the data in.
+ * NOTE: If upgrading from 0.10, this function is replacing the old
+ * function named tracker_extract_get_data() and has a few subtle
+ * differences. First there is a return value for success. Second
+ * there is also a @mimetype argument which should will be passed to
+ * each extractor.
  *
- * The @mime is usually in the format of "image/png" for example.
-
- * The @func is called by tracker-extract if an extractor plugin
- * matches the @mime.
+ * Returns: %TRUE if the extraction succeeded, %FALSE otherwise.
  *
- * Since: 0.8
- **/
-typedef struct {
-	const gchar *mime;
-	TrackerExtractMimeFunc func;
-} TrackerExtractData;
-
-/**
- * TrackerExtractDataFunc:
- *
- * This function is used by by tracker-extract to call into each
- * extractor to get a list of mime type and TrackerExtractMimeFunc
- * combinations.
- *
- * Returns: an array of #TrackerExtractData which must be NULL
- * terminated and must NOT be freed.
- *
- * Since: 0.6
- **/
-typedef TrackerExtractData * (*TrackerExtractDataFunc) (void);
-
-/**
- * tracker_extract_get_data:
- *
- *
- * This function must be provided by ALL extractors. This is merely
- * the declaration of the function which must be written by each
- * extractor. 
- * 
- * This is checked by tracker-extract by looking up the symbols for
- * each plugin and making sure this function exists. This is only
- * called by tracker-extract if a mime type in any of the
- * #TrackerExtractData structures returned matches the mime type of
- * the file being handled.
- *
- * Returns: a #TrackerExtractData pointer which should not be freed.
- * This pointer can be an array of #TrackerExtractData structures
- * where multiple mime types are supported.
- *
- * Since: 0.8
+ * Since: 0.12
  */
-TrackerExtractData *tracker_extract_get_data (void);
+gboolean tracker_extract_get_metadata (const gchar          *uri,
+                                       const gchar          *mimetype,
+                                       TrackerSparqlBuilder *preupdate,
+                                       TrackerSparqlBuilder *metadata,
+                                       GString              *where);
 
 G_END_DECLS
 
