@@ -33,12 +33,12 @@
 #warning Stayalive traces enabled
 #endif /* STAYALIVE_ENABLE_TRACE */
 
-#define THREAD_ENABLE_TRACE
-
 #ifdef THREAD_ENABLE_TRACE
 #warning Controller thread traces enabled
 #endif /* THREAD_ENABLE_TRACE */
 
+#define WATCHDOG_TIMEOUT 20
+
 typedef struct TrackerControllerPrivate TrackerControllerPrivate;
 typedef struct GetMetadataData GetMetadataData;
 
@@ -74,6 +74,8 @@ struct GetMetadataData {
 	gchar *uri;
 	gchar *mimetype;
 	gint fd; /* Only for fast queries */
+
+	GSource *watchdog_source;
 };
 
 #define TRACKER_EXTRACT_SERVICE   "org.freedesktop.Tracker1.Extract"
@@ -230,6 +232,37 @@ tracker_controller_class_init (TrackerControllerClass *klass)
 	g_type_class_add_private (object_class, sizeof (TrackerControllerPrivate));
 }
 
+static GSource *
+controller_timeout_source_new (guint       interval,
+                               GSourceFunc func,
+                               gpointer    user_data)
+{
+	GMainContext *context;
+	GSource *source;
+
+	context = g_main_context_get_thread_default ();
+
+	source = g_timeout_source_new_seconds (interval);
+	g_source_set_callback (source, func, user_data, NULL);
+	g_source_attach (source, context);
+
+	return source;
+}
+
+static gboolean
+watchdog_timeout_cb (gpointer user_data)
+{
+	GetMetadataData *data = user_data;
+	TrackerControllerPrivate *priv = data->controller->priv;
+
+	g_critical ("Extraction task for '%s' went rogue and took more than %d seconds. Forcing exit.",
+	            data->uri, WATCHDOG_TIMEOUT);
+
+	g_main_loop_quit (priv->main_loop);
+
+	return FALSE;
+}
+
 static GetMetadataData *
 metadata_data_new (TrackerController     *controller,
                    const gchar           *uri,
@@ -247,6 +280,9 @@ metadata_data_new (TrackerController     *controller,
 	data->invocation = invocation;
 	data->request = request;
 
+	data->watchdog_source = controller_timeout_source_new (WATCHDOG_TIMEOUT,
+	                                                       watchdog_timeout_cb,
+	                                                       data);
 	return data;
 }
 
@@ -259,6 +295,7 @@ metadata_data_free (GetMetadataData *data)
 	g_free (data->uri);
 	g_free (data->mimetype);
 	g_object_unref (data->cancellable);
+	g_source_destroy (data->watchdog_source);
 	g_slice_free (GetMetadataData, data);
 }
 
@@ -280,20 +317,9 @@ cancel_tasks_in_file (TrackerController *controller,
 
 		if (g_file_equal (task_file, file) ||
 		    g_file_has_prefix (task_file, file)) {
-			/* Mount path contains one of the files being processed */
-			if (!elem->next) {
-				/* The last element in the list is
-				 * the one currently being processed,
-				 * so exit abruptly.
-				 */
-				g_message ("Cancelled task ('%s') is currently being processed, quitting",
-				           data->uri);
-				g_main_loop_quit (priv->main_loop);
-			} else {
-				g_message ("Cancelling not yet processed task ('%s')",
-				           data->uri);
-				g_cancellable_cancel (data->cancellable);
-			}
+			/* Mount path contains some file being processed */
+			g_message ("Cancelling task ('%s')", data->uri);
+			g_cancellable_cancel (data->cancellable);
 		}
 
 		g_object_unref (task_file);
@@ -334,7 +360,6 @@ static void
 reset_shutdown_timeout (TrackerController *controller)
 {
 	TrackerControllerPrivate *priv;
-	GSource *source;
 
 	priv = controller->priv;
 
@@ -351,13 +376,9 @@ reset_shutdown_timeout (TrackerController *controller)
 		priv->shutdown_source = NULL;
 	}
 
-	source = g_timeout_source_new_seconds (priv->shutdown_timeout);
-	g_source_set_callback (source,
-	                       reset_shutdown_timeout_cb,
-	                       controller, NULL);
-
-	g_source_attach (source, priv->context);
-	priv->shutdown_source = source;
+	priv->shutdown_source = controller_timeout_source_new (priv->shutdown_timeout,
+	                                                       reset_shutdown_timeout_cb,
+	                                                       controller);
 }
 
 static void
@@ -419,18 +440,18 @@ get_metadata_cb (GObject      *object,
 	info = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (res));
 
 	if (info) {
-		if (tracker_sparql_builder_get_length (info->statements) > 0) {
-			const gchar *preupdate_str = NULL;
+		const gchar *preupdate, *statements, *where;
 
-			if (tracker_sparql_builder_get_length (info->preupdate) > 0) {
-				preupdate_str = tracker_sparql_builder_get_result (info->preupdate);
-			}
+		preupdate = tracker_extract_info_get_preupdate (info);
+		statements = tracker_extract_info_get_update (info);
+		where = tracker_extract_info_get_where_clause (info);
 
+		if (statements && *statements) {
 			g_dbus_method_invocation_return_value (data->invocation,
 			                                       g_variant_new ("(sss)",
-			                                                      preupdate_str ? preupdate_str : "",
-			                                                      tracker_sparql_builder_get_result (info->statements),
-			                                                      info->where ? info->where : ""));
+			                                                      preupdate ? preupdate : "",
+			                                                      statements,
+			                                                      where ? where : ""));
 		} else {
 			g_dbus_method_invocation_return_value (data->invocation,
 			                                       g_variant_new ("(sss)", "", "", ""));
@@ -527,6 +548,7 @@ get_metadata_fast_cb (GObject      *object,
 		GOutputStream *unix_output_stream;
 		GOutputStream *buffered_output_stream;
 		GDataOutputStream *data_output_stream;
+		const gchar *preupdate, *statements, *where;
 		GError *error = NULL;
 
 #ifdef THREAD_ENABLE_TRACE
@@ -541,15 +563,13 @@ get_metadata_fast_cb (GObject      *object,
 		g_data_output_stream_set_byte_order (G_DATA_OUTPUT_STREAM (data_output_stream),
 		                                     G_DATA_STREAM_BYTE_ORDER_HOST_ENDIAN);
 
-		if (tracker_sparql_builder_get_length (info->statements) > 0) {
-			const gchar *preupdate_str = NULL;
-
-			if (tracker_sparql_builder_get_length (info->preupdate) > 0) {
-				preupdate_str = tracker_sparql_builder_get_result (info->preupdate);
-			}
+		preupdate = tracker_extract_info_get_preupdate (info);
+		statements = tracker_extract_info_get_update (info);
+		where = tracker_extract_info_get_where_clause (info);
 
+		if (statements && *statements) {
 			g_data_output_stream_put_string (data_output_stream,
-			                                 preupdate_str ? preupdate_str : "",
+			                                 preupdate ? preupdate : "",
 			                                 NULL,
 			                                 &error);
 
@@ -562,7 +582,7 @@ get_metadata_fast_cb (GObject      *object,
 
 			if (!error) {
 				g_data_output_stream_put_string (data_output_stream,
-				                                 tracker_sparql_builder_get_result (info->statements),
+				                                 statements,
 				                                 NULL,
 				                                 &error);
 			}
@@ -574,9 +594,9 @@ get_metadata_fast_cb (GObject      *object,
 				                               &error);
 			}
 
-			if (!error && info->where) {
+			if (!error && where) {
 				g_data_output_stream_put_string (data_output_stream,
-				                                 info->where,
+				                                 where,
 				                                 NULL,
 				                                 &error);
 			}
