@@ -81,15 +81,6 @@ typedef struct {
 	const gchar *gps_direction;
 } MergeData;
 
-static void extract_jpeg (const gchar          *filename,
-                          TrackerSparqlBuilder *preupdate,
-                          TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "image/jpeg", extract_jpeg },
-	{ NULL, NULL }
-};
-
 struct tej_error_mgr {
 	struct jpeg_error_mgr jpeg;
 	jmp_buf setjmp_buffer;
@@ -148,10 +139,12 @@ guess_dlna_profile (gint          width,
 	return FALSE;
 }
 
-static void
-extract_jpeg (const gchar          *uri,
-              TrackerSparqlBuilder *preupdate,
-              TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	struct jpeg_decompress_struct cinfo;
 	struct tej_error_mgr tejerr;
@@ -166,8 +159,8 @@ extract_jpeg (const gchar          *uri,
 	gchar *comment = NULL;
 	const gchar *dlna_profile;
 	GPtrArray *keywords;
+	gboolean success = TRUE;
 	guint i;
-	GString *where = NULL;
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 
@@ -175,14 +168,14 @@ extract_jpeg (const gchar          *uri,
 
 	if (size < 18) {
 		g_free (filename);
-		return;
+		return FALSE;
 	}
 
-	f = tracker_file_open (filename);
+	f = tracker_file_open (filename, "rb", FALSE);
 	g_free (filename);
 
 	if (!f) {
-		return;
+		return FALSE;
 	}
 
 	tracker_sparql_builder_predicate (metadata, "a");
@@ -193,6 +186,7 @@ extract_jpeg (const gchar          *uri,
 	cinfo.err = jpeg_std_error (&tejerr.jpeg);
 	tejerr.jpeg.error_exit = extract_jpeg_error_exit;
 	if (setjmp (tejerr.setjmp_buffer)) {
+		success = FALSE;
 		goto fail;
 	}
 
@@ -418,10 +412,6 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->license);
 	}
 
-        if (xd->regions) {
-	        tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-        }
-
 	if (id->keywords) {
 		tracker_keywords_parse (keywords, id->keywords);
 	}
@@ -448,10 +438,6 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -727,11 +713,6 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_double (metadata, value);
 	}
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	jpeg_destroy_decompress (&cinfo);
 
 	tracker_exif_free (ed);
@@ -741,10 +722,6 @@ extract_jpeg (const gchar          *uri,
 
 fail:
 	tracker_file_close (f, FALSE);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return success;
 }
