@@ -70,16 +70,6 @@ typedef struct {
 	const gchar *disclaimer;
 } PngData;
 
-static void extract_png (const gchar          *filename,
-                         TrackerSparqlBuilder *preupdate,
-                         TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "image/png", extract_png },
-	{ "sketch/png", extract_png },
-	{ NULL, NULL }
-};
-
 static gchar *
 rfc1123_to_iso8601_date (const gchar *date)
 {
@@ -89,111 +79,10 @@ rfc1123_to_iso8601_date (const gchar *date)
 	return tracker_date_format_to_iso8601 (date, RFC1123_DATE_FORMAT);
 }
 
-/* Handle raw profiles by Imagemagick (at least). Hex encoded with
- * line-changes and other (undocumented/unofficial) twists.
- */
-static gchar *
-raw_profile_new (const gchar *input,
-                 const guint  input_length,
-                 guint       *output_length)
-{
-	static const gchar* const lut = "0123456789abcdef";
-	gchar *output;
-	const gchar *ptr;
-	const gchar *length_ptr;
-	gsize size;
-	gchar *length_str;
-	guint length;
-
-	size_t len;
-	size_t i;
-	size_t o;
-	char *p;
-	char *q;
-
-	ptr = input;
-
-	if (*ptr != '\n') {
-		return NULL;
-	}
-
-	ptr++;
-
-	if (!g_ascii_isalpha (*ptr)) {
-		return NULL;
-	}
-
-	/* Skip the type string */
-	do {
-		ptr++;
-	} while (g_ascii_isalpha (*ptr));
-
-	if (*ptr != '\n') {
-		return NULL;
-	}
-
-	/* Hop over whitespaces */
-	do {
-		ptr++;
-	} while (*ptr == ' ');
-
-	if (!g_ascii_isdigit (*ptr)) {
-		return NULL;
-	}
-
-	/* Get the length string */
-	length_ptr = ptr;
-	size = 1;
-
-	do {
-		ptr++;
-		size++;
-	} while (g_ascii_isdigit (*ptr));
-
-	length_str = g_strndup (length_ptr, size - 1);
-
-	if (*ptr != '\n') {
-		return NULL;
-	}
-
-	ptr++;
-
-	length = atoi (length_str);
-	g_free (length_str);
-
-	len = length;
-	i = 0;
-	o = 0;
-
-	output = malloc (length + 1); /* A bit less with non-valid */
-
-	o = 0;
-	while (o < len) {
-		do {
-			gchar a = ptr[i];
-			p = strchr (lut, a);
-			i++;
-		} while (p == 0);
-
-		do {
-			gchar b = ptr[i];
-			q = strchr (lut, b);
-			i++;
-		} while (q == 0);
-
-		output[o] = (((p - lut) << 4) | (q - lut));
-		o++;
-	}
-
-	output[o] = '\0';
-	*output_length = o;
-
-	return output;
-}
-
 static void
 read_metadata (TrackerSparqlBuilder *preupdate,
                TrackerSparqlBuilder *metadata,
+               GString              *where,
                png_structp           png_ptr,
                png_infop             info_ptr,
                png_infop             end_ptr,
@@ -210,7 +99,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 	gint i;
 	gint found;
 	GPtrArray *keywords;
-	GString *where = NULL;
 
 	info_ptrs[0] = info_ptr;
 	info_ptrs[1] = end_ptr;
@@ -226,74 +114,32 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 				continue;
 			}
 
-#if defined(HAVE_EXEMPI) && defined(PNG_iTXt_SUPPORTED)
+	#if defined(HAVE_EXEMPI) && defined(PNG_iTXt_SUPPORTED)
 			if (g_strcmp0 ("XML:com.adobe.xmp", text_ptr[i].key) == 0) {
 				/* ATM tracker_extract_xmp_read supports setting xd
 				 * multiple times, keep it that way as here it's
 				 * theoretically possible that the function gets
-				 * called multiple times
+				 * called multiple times 
 				 */
 				xd = tracker_xmp_new (text_ptr[i].text,
-				                      text_ptr[i].itxt_length,
-				                      uri);
-
+					              text_ptr[i].itxt_length,
+					              uri);
 				continue;
 			}
+	#endif
 
-			if (g_strcmp0 ("Raw profile type xmp", text_ptr[i].key) == 0) {
-				gchar *xmp_buffer;
-				guint xmp_buffer_length = 0;
-				guint input_len;
-
-				if (text_ptr[i].text_length) {
-					input_len = text_ptr[i].text_length;
-				} else {
-					input_len = text_ptr[i].itxt_length;
-				}
-
-				xmp_buffer = raw_profile_new (text_ptr[i].text,
-				                              input_len,
-				                              &xmp_buffer_length);
-
-				if (xmp_buffer) {
-					xd = tracker_xmp_new (xmp_buffer,
-					                      xmp_buffer_length,
-					                      uri);
-				}
-
-				g_free (xmp_buffer);
-
-				continue;
-			}
-#endif
-
-#if defined(HAVE_LIBEXIF) && defined(PNG_iTXt_SUPPORTED)
+	#if defined(HAVE_LIBEXIF) && defined(PNG_iTXt_SUPPORTED)
+			/* I'm not certain this is the key for EXIF. Using key according to
+			 * this document about exiftool:
+			 * http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/PNG.html#TextualData 
+			 */
 			if (g_strcmp0 ("Raw profile type exif", text_ptr[i].key) == 0) {
-				gchar *exif_buffer;
-				guint exif_buffer_length = 0;
-				guint input_len;
-
-				if (text_ptr[i].text_length) {
-					input_len = text_ptr[i].text_length;
-				} else {
-					input_len = text_ptr[i].itxt_length;
-				}
-
-				exif_buffer = raw_profile_new (text_ptr[i].text,
-				                               input_len,
-				                               &exif_buffer_length);
-
-				if (exif_buffer) {
-					ed = tracker_exif_new (exif_buffer,
-					                       exif_buffer_length,
-					                       uri);
-				}
-
-				g_free (exif_buffer);
-
+				ed = tracker_exif_new (text_ptr[i].text,
+					               text_ptr[i].itxt_length,
+					               uri);
 				continue;
 			}
-#endif /* HAVE_LIBEXIF */
+	#endif /* HAVE_LIBEXIF */
 
 			if (g_strcmp0 (text_ptr[i].key, "Author") == 0) {
 				pd.author = text_ptr[i].text;
@@ -577,12 +423,11 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 
 		if (xd->address || xd->state || xd->country || xd->city)  {
 			gchar *addruri;
-
 			addruri = tracker_sparql_get_uuid_urn ();
 
 			tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
-			tracker_sparql_builder_object_iri (metadata, addruri);
-
+			tracker_sparql_builder_object_iri (metadata, addruri);			
+			
 			tracker_sparql_builder_insert_open (preupdate, NULL);
 			tracker_sparql_builder_subject_iri (preupdate, addruri);
 
@@ -653,10 +498,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_object_double (metadata, value);
 	}
 
-	if (xd->regions) {
-		tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-	}
-
 	for (i = 0; i < keywords->len; i++) {
 		gchar *p, *escaped, *var;
 
@@ -679,10 +520,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -691,11 +528,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 	}
 	g_ptr_array_free (keywords, TRUE);
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	tracker_exif_free (ed);
 	tracker_xmp_free (xd);
 	g_free (pd.creation_time);
@@ -743,10 +575,12 @@ guess_dlna_profile (gint          depth,
 	return FALSE;
 }
 
-static void
-extract_png (const gchar          *uri,
-             TrackerSparqlBuilder *preupdate,
-             TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	goffset size;
 	FILE *f;
@@ -765,14 +599,14 @@ extract_png (const gchar          *uri,
 	size = tracker_file_get_size (filename);
 
 	if (size < 64) {
-		return;
+		return FALSE;
 	}
 
-	f = tracker_file_open (filename);
+	f = tracker_file_open (filename, "r", FALSE);
 	g_free (filename);
 
 	if (!f) {
-		return;
+		return FALSE;
 	}
 
 	png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING,
@@ -781,27 +615,27 @@ extract_png (const gchar          *uri,
 	                                  NULL);
 	if (!png_ptr) {
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	info_ptr = png_create_info_struct (png_ptr);
 	if (!info_ptr) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	end_ptr = png_create_info_struct (png_ptr);
 	if (!end_ptr) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	if (setjmp (png_jmpbuf (png_ptr))) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	png_init_io (png_ptr, f);
@@ -818,7 +652,7 @@ extract_png (const gchar          *uri,
 	                   &filter_type)) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	/* Read the image. FIXME We should be able to skip this step and
@@ -845,7 +679,7 @@ extract_png (const gchar          *uri,
 	tracker_sparql_builder_object (metadata, "nfo:Image");
 	tracker_sparql_builder_object (metadata, "nmm:Photo");
 
-	read_metadata (preupdate, metadata, png_ptr, info_ptr, end_ptr, uri);
+	read_metadata (preupdate, metadata, where, png_ptr, info_ptr, end_ptr, uri);
 
 	tracker_sparql_builder_predicate (metadata, "nfo:width");
 	tracker_sparql_builder_object_int64 (metadata, width);
@@ -860,10 +694,6 @@ extract_png (const gchar          *uri,
 
 	png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
 	tracker_file_close (f, FALSE);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return TRUE;
 }
